Package org.tensorflow.framework
Class CostGraphDef.Node.OutputInfo.Builder
java.lang.Object
com.google.protobuf.AbstractMessageLite.Builder
com.google.protobuf.AbstractMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
com.google.protobuf.GeneratedMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
org.tensorflow.framework.CostGraphDef.Node.OutputInfo.Builder
- All Implemented Interfaces:
com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Cloneable,CostGraphDef.Node.OutputInfoOrBuilder
- Enclosing class:
CostGraphDef.Node.OutputInfo
public static final class CostGraphDef.Node.OutputInfo.Builder
extends com.google.protobuf.GeneratedMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
implements CostGraphDef.Node.OutputInfoOrBuilder
Outputs of this node.Protobuf type
tensorflow.CostGraphDef.Node.OutputInfo-
Method Summary
Modifier and TypeMethodDescriptionbuild()clear()If >= 0, the output is an alias of an input..tensorflow.DataType dtype = 4;.tensorflow.TensorShapeProto shape = 3;int64 size = 1;longIf >= 0, the output is an alias of an input.static final com.google.protobuf.Descriptors.Descriptorcom.google.protobuf.Descriptors.DescriptorgetDtype().tensorflow.DataType dtype = 4;int.tensorflow.DataType dtype = 4;getShape().tensorflow.TensorShapeProto shape = 3;.tensorflow.TensorShapeProto shape = 3;.tensorflow.TensorShapeProto shape = 3;longgetSize()int64 size = 1;booleanhasShape().tensorflow.TensorShapeProto shape = 3;protected com.google.protobuf.GeneratedMessage.FieldAccessorTablefinal booleanmergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) mergeFrom(com.google.protobuf.Message other) mergeShape(TensorShapeProto value) .tensorflow.TensorShapeProto shape = 3;setAliasInputPort(long value) If >= 0, the output is an alias of an input..tensorflow.DataType dtype = 4;setDtypeValue(int value) .tensorflow.DataType dtype = 4;setShape(TensorShapeProto value) .tensorflow.TensorShapeProto shape = 3;setShape(TensorShapeProto.Builder builderForValue) .tensorflow.TensorShapeProto shape = 3;setSize(long value) int64 size = 1;Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageExceptionMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.Message.Builder
mergeDelimitedFrom, mergeDelimitedFromMethods inherited from interface com.google.protobuf.MessageLite.Builder
mergeFromMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
-
clear
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
-
mergeFrom
-
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>
-
mergeFrom
public CostGraphDef.Node.OutputInfo.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<CostGraphDef.Node.OutputInfo.Builder>- Throws:
IOException
-
getSize
public long getSize()int64 size = 1;- Specified by:
getSizein interfaceCostGraphDef.Node.OutputInfoOrBuilder- Returns:
- The size.
-
setSize
int64 size = 1;- Parameters:
value- The size to set.- Returns:
- This builder for chaining.
-
clearSize
int64 size = 1;- Returns:
- This builder for chaining.
-
getAliasInputPort
public long getAliasInputPort()If >= 0, the output is an alias of an input. Note that an alias input may itself be an alias. The algorithm will therefore need to follow those pointers.
int64 alias_input_port = 2;- Specified by:
getAliasInputPortin interfaceCostGraphDef.Node.OutputInfoOrBuilder- Returns:
- The aliasInputPort.
-
setAliasInputPort
If >= 0, the output is an alias of an input. Note that an alias input may itself be an alias. The algorithm will therefore need to follow those pointers.
int64 alias_input_port = 2;- Parameters:
value- The aliasInputPort to set.- Returns:
- This builder for chaining.
-
clearAliasInputPort
If >= 0, the output is an alias of an input. Note that an alias input may itself be an alias. The algorithm will therefore need to follow those pointers.
int64 alias_input_port = 2;- Returns:
- This builder for chaining.
-
hasShape
public boolean hasShape().tensorflow.TensorShapeProto shape = 3;- Specified by:
hasShapein interfaceCostGraphDef.Node.OutputInfoOrBuilder- Returns:
- Whether the shape field is set.
-
getShape
.tensorflow.TensorShapeProto shape = 3;- Specified by:
getShapein interfaceCostGraphDef.Node.OutputInfoOrBuilder- Returns:
- The shape.
-
setShape
.tensorflow.TensorShapeProto shape = 3; -
setShape
.tensorflow.TensorShapeProto shape = 3; -
mergeShape
.tensorflow.TensorShapeProto shape = 3; -
clearShape
.tensorflow.TensorShapeProto shape = 3; -
getShapeBuilder
.tensorflow.TensorShapeProto shape = 3; -
getShapeOrBuilder
.tensorflow.TensorShapeProto shape = 3;- Specified by:
getShapeOrBuilderin interfaceCostGraphDef.Node.OutputInfoOrBuilder
-
getDtypeValue
public int getDtypeValue().tensorflow.DataType dtype = 4;- Specified by:
getDtypeValuein interfaceCostGraphDef.Node.OutputInfoOrBuilder- Returns:
- The enum numeric value on the wire for dtype.
-
setDtypeValue
.tensorflow.DataType dtype = 4;- Parameters:
value- The enum numeric value on the wire for dtype to set.- Returns:
- This builder for chaining.
-
getDtype
.tensorflow.DataType dtype = 4;- Specified by:
getDtypein interfaceCostGraphDef.Node.OutputInfoOrBuilder- Returns:
- The dtype.
-
setDtype
.tensorflow.DataType dtype = 4;- Parameters:
value- The dtype to set.- Returns:
- This builder for chaining.
- Throws:
IllegalArgumentException- if UNRECOGNIZED is provided.
-
clearDtype
.tensorflow.DataType dtype = 4;- Returns:
- This builder for chaining.
-