Class VariableDef

java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessage
org.tensorflow.framework.VariableDef
All Implemented Interfaces:
com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable, VariableDefOrBuilder

@Generated public final class VariableDef extends com.google.protobuf.GeneratedMessage implements VariableDefOrBuilder
 Protocol buffer representing a Variable.
 
Protobuf type tensorflow.VariableDef
See Also:
  • Field Details

    • VARIABLE_NAME_FIELD_NUMBER

      public static final int VARIABLE_NAME_FIELD_NUMBER
      See Also:
    • INITIAL_VALUE_NAME_FIELD_NUMBER

      public static final int INITIAL_VALUE_NAME_FIELD_NUMBER
      See Also:
    • INITIALIZER_NAME_FIELD_NUMBER

      public static final int INITIALIZER_NAME_FIELD_NUMBER
      See Also:
    • SNAPSHOT_NAME_FIELD_NUMBER

      public static final int SNAPSHOT_NAME_FIELD_NUMBER
      See Also:
    • SAVE_SLICE_INFO_DEF_FIELD_NUMBER

      public static final int SAVE_SLICE_INFO_DEF_FIELD_NUMBER
      See Also:
    • IS_RESOURCE_FIELD_NUMBER

      public static final int IS_RESOURCE_FIELD_NUMBER
      See Also:
    • TRAINABLE_FIELD_NUMBER

      public static final int TRAINABLE_FIELD_NUMBER
      See Also:
    • SYNCHRONIZATION_FIELD_NUMBER

      public static final int SYNCHRONIZATION_FIELD_NUMBER
      See Also:
    • AGGREGATION_FIELD_NUMBER

      public static final int AGGREGATION_FIELD_NUMBER
      See Also:
  • Method Details

    • getDescriptor

      public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
    • getDescriptorForType

      public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
      Specified by:
      getDescriptorForType in interface com.google.protobuf.MessageOrBuilder
      Overrides:
      getDescriptorForType in class com.google.protobuf.GeneratedMessage
    • internalGetFieldAccessorTable

      protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
      Specified by:
      internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage
    • getVariableName

      public String getVariableName()
       Name of the variable tensor.
       
      string variable_name = 1;
      Specified by:
      getVariableName in interface VariableDefOrBuilder
      Returns:
      The variableName.
    • getVariableNameBytes

      public com.google.protobuf.ByteString getVariableNameBytes()
       Name of the variable tensor.
       
      string variable_name = 1;
      Specified by:
      getVariableNameBytes in interface VariableDefOrBuilder
      Returns:
      The bytes for variableName.
    • getInitialValueName

      public String getInitialValueName()
       Name of the tensor holding the variable's initial value.
       
      string initial_value_name = 6;
      Specified by:
      getInitialValueName in interface VariableDefOrBuilder
      Returns:
      The initialValueName.
    • getInitialValueNameBytes

      public com.google.protobuf.ByteString getInitialValueNameBytes()
       Name of the tensor holding the variable's initial value.
       
      string initial_value_name = 6;
      Specified by:
      getInitialValueNameBytes in interface VariableDefOrBuilder
      Returns:
      The bytes for initialValueName.
    • getInitializerName

      public String getInitializerName()
       Name of the initializer op.
       
      string initializer_name = 2;
      Specified by:
      getInitializerName in interface VariableDefOrBuilder
      Returns:
      The initializerName.
    • getInitializerNameBytes

      public com.google.protobuf.ByteString getInitializerNameBytes()
       Name of the initializer op.
       
      string initializer_name = 2;
      Specified by:
      getInitializerNameBytes in interface VariableDefOrBuilder
      Returns:
      The bytes for initializerName.
    • getSnapshotName

      public String getSnapshotName()
       Name of the snapshot tensor.
       
      string snapshot_name = 3;
      Specified by:
      getSnapshotName in interface VariableDefOrBuilder
      Returns:
      The snapshotName.
    • getSnapshotNameBytes

      public com.google.protobuf.ByteString getSnapshotNameBytes()
       Name of the snapshot tensor.
       
      string snapshot_name = 3;
      Specified by:
      getSnapshotNameBytes in interface VariableDefOrBuilder
      Returns:
      The bytes for snapshotName.
    • hasSaveSliceInfoDef

      public boolean hasSaveSliceInfoDef()
       Support for saving variables as slices of a larger variable.
       
      .tensorflow.SaveSliceInfoDef save_slice_info_def = 4;
      Specified by:
      hasSaveSliceInfoDef in interface VariableDefOrBuilder
      Returns:
      Whether the saveSliceInfoDef field is set.
    • getSaveSliceInfoDef

      public SaveSliceInfoDef getSaveSliceInfoDef()
       Support for saving variables as slices of a larger variable.
       
      .tensorflow.SaveSliceInfoDef save_slice_info_def = 4;
      Specified by:
      getSaveSliceInfoDef in interface VariableDefOrBuilder
      Returns:
      The saveSliceInfoDef.
    • getSaveSliceInfoDefOrBuilder

      public SaveSliceInfoDefOrBuilder getSaveSliceInfoDefOrBuilder()
       Support for saving variables as slices of a larger variable.
       
      .tensorflow.SaveSliceInfoDef save_slice_info_def = 4;
      Specified by:
      getSaveSliceInfoDefOrBuilder in interface VariableDefOrBuilder
    • getIsResource

      public boolean getIsResource()
       Whether to represent this as a ResourceVariable.
       
      bool is_resource = 5;
      Specified by:
      getIsResource in interface VariableDefOrBuilder
      Returns:
      The isResource.
    • getTrainable

      public boolean getTrainable()
       Whether this variable should be trained.
       
      bool trainable = 7;
      Specified by:
      getTrainable in interface VariableDefOrBuilder
      Returns:
      The trainable.
    • getSynchronizationValue

      public int getSynchronizationValue()
       Indicates when a distributed variable will be synced.
       
      .tensorflow.VariableSynchronization synchronization = 8;
      Specified by:
      getSynchronizationValue in interface VariableDefOrBuilder
      Returns:
      The enum numeric value on the wire for synchronization.
    • getSynchronization

      public VariableSynchronization getSynchronization()
       Indicates when a distributed variable will be synced.
       
      .tensorflow.VariableSynchronization synchronization = 8;
      Specified by:
      getSynchronization in interface VariableDefOrBuilder
      Returns:
      The synchronization.
    • getAggregationValue

      public int getAggregationValue()
       Indicates how a distributed variable will be aggregated.
       
      .tensorflow.VariableAggregation aggregation = 9;
      Specified by:
      getAggregationValue in interface VariableDefOrBuilder
      Returns:
      The enum numeric value on the wire for aggregation.
    • getAggregation

      public VariableAggregation getAggregation()
       Indicates how a distributed variable will be aggregated.
       
      .tensorflow.VariableAggregation aggregation = 9;
      Specified by:
      getAggregation in interface VariableDefOrBuilder
      Returns:
      The aggregation.
    • isInitialized

      public final boolean isInitialized()
      Specified by:
      isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
      Overrides:
      isInitialized in class com.google.protobuf.GeneratedMessage
    • writeTo

      public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException
      Specified by:
      writeTo in interface com.google.protobuf.MessageLite
      Overrides:
      writeTo in class com.google.protobuf.GeneratedMessage
      Throws:
      IOException
    • getSerializedSize

      public int getSerializedSize()
      Specified by:
      getSerializedSize in interface com.google.protobuf.MessageLite
      Overrides:
      getSerializedSize in class com.google.protobuf.GeneratedMessage
    • equals

      public boolean equals(Object obj)
      Specified by:
      equals in interface com.google.protobuf.Message
      Overrides:
      equals in class com.google.protobuf.AbstractMessage
    • hashCode

      public int hashCode()
      Specified by:
      hashCode in interface com.google.protobuf.Message
      Overrides:
      hashCode in class com.google.protobuf.AbstractMessage
    • parseFrom

      public static VariableDef parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static VariableDef parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static VariableDef parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static VariableDef parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static VariableDef parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static VariableDef parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static VariableDef parseFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static VariableDef parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static VariableDef parseDelimitedFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static VariableDef parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseFrom

      public static VariableDef parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static VariableDef parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • newBuilderForType

      public VariableDef.Builder newBuilderForType()
      Specified by:
      newBuilderForType in interface com.google.protobuf.Message
      Specified by:
      newBuilderForType in interface com.google.protobuf.MessageLite
    • newBuilder

      public static VariableDef.Builder newBuilder()
    • newBuilder

      public static VariableDef.Builder newBuilder(VariableDef prototype)
    • toBuilder

      public VariableDef.Builder toBuilder()
      Specified by:
      toBuilder in interface com.google.protobuf.Message
      Specified by:
      toBuilder in interface com.google.protobuf.MessageLite
    • newBuilderForType

      protected VariableDef.Builder newBuilderForType(com.google.protobuf.AbstractMessage.BuilderParent parent)
      Overrides:
      newBuilderForType in class com.google.protobuf.AbstractMessage
    • getDefaultInstance

      public static VariableDef getDefaultInstance()
    • parser

      public static com.google.protobuf.Parser<VariableDef> parser()
    • getParserForType

      public com.google.protobuf.Parser<VariableDef> getParserForType()
      Specified by:
      getParserForType in interface com.google.protobuf.Message
      Specified by:
      getParserForType in interface com.google.protobuf.MessageLite
      Overrides:
      getParserForType in class com.google.protobuf.GeneratedMessage
    • getDefaultInstanceForType

      public VariableDef getDefaultInstanceForType()
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder