Package tensorflow

Class SavedObjectGraphOuterClass.SavedUserObject

java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessage
tensorflow.SavedObjectGraphOuterClass.SavedUserObject
All Implemented Interfaces:
com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable, SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
Enclosing class:
SavedObjectGraphOuterClass

public static final class SavedObjectGraphOuterClass.SavedUserObject extends com.google.protobuf.GeneratedMessage implements SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
 A SavedUserObject is an object (in the object-oriented language of the
 TensorFlow program) of some user- or framework-defined class other than
 those handled specifically by the other kinds of SavedObjects.

 This object cannot be evaluated as a tensor, and therefore cannot be bound
 to an input of a function.
 
Protobuf type tensorflow.SavedUserObject
See Also:
  • Field Details

  • Method Details

    • getDescriptor

      public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
    • getDescriptorForType

      public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
      Specified by:
      getDescriptorForType in interface com.google.protobuf.MessageOrBuilder
      Overrides:
      getDescriptorForType in class com.google.protobuf.GeneratedMessage
    • internalGetFieldAccessorTable

      protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
      Specified by:
      internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage
    • getIdentifier

      public String getIdentifier()
       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Specified by:
      getIdentifier in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The identifier.
    • getIdentifierBytes

      public com.google.protobuf.ByteString getIdentifierBytes()
       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Specified by:
      getIdentifierBytes in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The bytes for identifier.
    • hasVersion

      public boolean hasVersion()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
      Specified by:
      hasVersion in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      Whether the version field is set.
    • getVersion

      public VersionDef getVersion()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
      Specified by:
      getVersion in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The version.
    • getVersionOrBuilder

      public VersionDefOrBuilder getVersionOrBuilder()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
      Specified by:
      getVersionOrBuilder in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
    • getMetadata

      @Deprecated public String getMetadata()
      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Specified by:
      getMetadata in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The metadata.
    • getMetadataBytes

      @Deprecated public com.google.protobuf.ByteString getMetadataBytes()
      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Specified by:
      getMetadataBytes in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The bytes for metadata.
    • isInitialized

      public final boolean isInitialized()
      Specified by:
      isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
      Overrides:
      isInitialized in class com.google.protobuf.GeneratedMessage
    • writeTo

      public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException
      Specified by:
      writeTo in interface com.google.protobuf.MessageLite
      Overrides:
      writeTo in class com.google.protobuf.GeneratedMessage
      Throws:
      IOException
    • getSerializedSize

      public int getSerializedSize()
      Specified by:
      getSerializedSize in interface com.google.protobuf.MessageLite
      Overrides:
      getSerializedSize in class com.google.protobuf.GeneratedMessage
    • equals

      public boolean equals(Object obj)
      Specified by:
      equals in interface com.google.protobuf.Message
      Overrides:
      equals in class com.google.protobuf.AbstractMessage
    • hashCode

      public int hashCode()
      Specified by:
      hashCode in interface com.google.protobuf.Message
      Overrides:
      hashCode in class com.google.protobuf.AbstractMessage
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseDelimitedFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static SavedObjectGraphOuterClass.SavedUserObject parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • newBuilderForType

      Specified by:
      newBuilderForType in interface com.google.protobuf.Message
      Specified by:
      newBuilderForType in interface com.google.protobuf.MessageLite
    • newBuilder

    • newBuilder

    • toBuilder

      Specified by:
      toBuilder in interface com.google.protobuf.Message
      Specified by:
      toBuilder in interface com.google.protobuf.MessageLite
    • newBuilderForType

      protected SavedObjectGraphOuterClass.SavedUserObject.Builder newBuilderForType(com.google.protobuf.AbstractMessage.BuilderParent parent)
      Overrides:
      newBuilderForType in class com.google.protobuf.AbstractMessage
    • getDefaultInstance

      public static SavedObjectGraphOuterClass.SavedUserObject getDefaultInstance()
    • parser

      public static com.google.protobuf.Parser<SavedObjectGraphOuterClass.SavedUserObject> parser()
    • getParserForType

      public com.google.protobuf.Parser<SavedObjectGraphOuterClass.SavedUserObject> getParserForType()
      Specified by:
      getParserForType in interface com.google.protobuf.Message
      Specified by:
      getParserForType in interface com.google.protobuf.MessageLite
      Overrides:
      getParserForType in class com.google.protobuf.GeneratedMessage
    • getDefaultInstanceForType

      public SavedObjectGraphOuterClass.SavedUserObject getDefaultInstanceForType()
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder