Package tensorflow

Class SavedObjectGraphOuterClass.SavedUserObject.Builder

java.lang.Object
com.google.protobuf.AbstractMessageLite.Builder
com.google.protobuf.AbstractMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
com.google.protobuf.GeneratedMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
tensorflow.SavedObjectGraphOuterClass.SavedUserObject.Builder
All Implemented Interfaces:
com.google.protobuf.Message.Builder, com.google.protobuf.MessageLite.Builder, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Cloneable, SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
Enclosing class:
SavedObjectGraphOuterClass.SavedUserObject

public static final class SavedObjectGraphOuterClass.SavedUserObject.Builder extends com.google.protobuf.GeneratedMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder> implements SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
 A SavedUserObject is an object (in the object-oriented language of the
 TensorFlow program) of some user- or framework-defined class other than
 those handled specifically by the other kinds of SavedObjects.

 This object cannot be evaluated as a tensor, and therefore cannot be bound
 to an input of a function.
 
Protobuf type tensorflow.SavedUserObject
  • Method Details

    • getDescriptor

      public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
    • internalGetFieldAccessorTable

      protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()
      Specified by:
      internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
    • clear

      Specified by:
      clear in interface com.google.protobuf.Message.Builder
      Specified by:
      clear in interface com.google.protobuf.MessageLite.Builder
      Overrides:
      clear in class com.google.protobuf.GeneratedMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
    • getDescriptorForType

      public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
      Specified by:
      getDescriptorForType in interface com.google.protobuf.Message.Builder
      Specified by:
      getDescriptorForType in interface com.google.protobuf.MessageOrBuilder
      Overrides:
      getDescriptorForType in class com.google.protobuf.GeneratedMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
    • getDefaultInstanceForType

      public SavedObjectGraphOuterClass.SavedUserObject getDefaultInstanceForType()
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder
    • build

      Specified by:
      build in interface com.google.protobuf.Message.Builder
      Specified by:
      build in interface com.google.protobuf.MessageLite.Builder
    • buildPartial

      Specified by:
      buildPartial in interface com.google.protobuf.Message.Builder
      Specified by:
      buildPartial in interface com.google.protobuf.MessageLite.Builder
    • mergeFrom

      public SavedObjectGraphOuterClass.SavedUserObject.Builder mergeFrom(com.google.protobuf.Message other)
      Specified by:
      mergeFrom in interface com.google.protobuf.Message.Builder
      Overrides:
      mergeFrom in class com.google.protobuf.AbstractMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
    • mergeFrom

    • isInitialized

      public final boolean isInitialized()
      Specified by:
      isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
      Overrides:
      isInitialized in class com.google.protobuf.GeneratedMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
    • mergeFrom

      public SavedObjectGraphOuterClass.SavedUserObject.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Specified by:
      mergeFrom in interface com.google.protobuf.Message.Builder
      Specified by:
      mergeFrom in interface com.google.protobuf.MessageLite.Builder
      Overrides:
      mergeFrom in class com.google.protobuf.AbstractMessage.Builder<SavedObjectGraphOuterClass.SavedUserObject.Builder>
      Throws:
      IOException
    • getIdentifier

      public String getIdentifier()
       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Specified by:
      getIdentifier in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The identifier.
    • getIdentifierBytes

      public com.google.protobuf.ByteString getIdentifierBytes()
       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Specified by:
      getIdentifierBytes in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The bytes for identifier.
    • setIdentifier

       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Parameters:
      value - The identifier to set.
      Returns:
      This builder for chaining.
    • clearIdentifier

       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Returns:
      This builder for chaining.
    • setIdentifierBytes

      public SavedObjectGraphOuterClass.SavedUserObject.Builder setIdentifierBytes(com.google.protobuf.ByteString value)
       Corresponds to a registration of the type to use in the loading program.
       
      string identifier = 1;
      Parameters:
      value - The bytes for identifier to set.
      Returns:
      This builder for chaining.
    • hasVersion

      public boolean hasVersion()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
      Specified by:
      hasVersion in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      Whether the version field is set.
    • getVersion

      public VersionDef getVersion()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
      Specified by:
      getVersion in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The version.
    • setVersion

       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
    • setVersion

       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
    • mergeVersion

       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
    • clearVersion

       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
    • getVersionBuilder

      public VersionDef.Builder getVersionBuilder()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
    • getVersionOrBuilder

      public VersionDefOrBuilder getVersionOrBuilder()
       Version information from the producer of this SavedUserObject.
       
      .tensorflow.VersionDef version = 2;
      Specified by:
      getVersionOrBuilder in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
    • getMetadata

      @Deprecated public String getMetadata()
      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Specified by:
      getMetadata in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The metadata.
    • getMetadataBytes

      @Deprecated public com.google.protobuf.ByteString getMetadataBytes()
      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Specified by:
      getMetadataBytes in interface SavedObjectGraphOuterClass.SavedUserObjectOrBuilder
      Returns:
      The bytes for metadata.
    • setMetadata

      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Parameters:
      value - The metadata to set.
      Returns:
      This builder for chaining.
    • clearMetadata

      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Returns:
      This builder for chaining.
    • setMetadataBytes

      @Deprecated public SavedObjectGraphOuterClass.SavedUserObject.Builder setMetadataBytes(com.google.protobuf.ByteString value)
      Deprecated.
      tensorflow.SavedUserObject.metadata is deprecated. See tensorflow/core/protobuf/saved_object_graph.proto;l=122
       Metadata for deserializing this object.
      
       Deprecated! At the time of deprecation, Keras was the only user of this
       field, and its saving and loading code will be updated shortly.
       Please save your application-specific metadata to a separate file.
       
      string metadata = 3 [deprecated = true];
      Parameters:
      value - The bytes for metadata to set.
      Returns:
      This builder for chaining.