Package tensorflow.serving
Class Classification.ClassificationRequest.Builder
java.lang.Object
com.google.protobuf.AbstractMessageLite.Builder
com.google.protobuf.AbstractMessage.Builder<Classification.ClassificationRequest.Builder>
com.google.protobuf.GeneratedMessage.Builder<Classification.ClassificationRequest.Builder>
tensorflow.serving.Classification.ClassificationRequest.Builder
- All Implemented Interfaces:
com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Cloneable,Classification.ClassificationRequestOrBuilder
- Enclosing class:
Classification.ClassificationRequest
public static final class Classification.ClassificationRequest.Builder
extends com.google.protobuf.GeneratedMessage.Builder<Classification.ClassificationRequest.Builder>
implements Classification.ClassificationRequestOrBuilder
Protobuf type
tensorflow.serving.ClassificationRequest-
Method Summary
Modifier and TypeMethodDescriptionbuild()clear()Input data.Model Specification.static final com.google.protobuf.Descriptors.Descriptorcom.google.protobuf.Descriptors.DescriptorgetInput()Input data.Input data.Input data.Model Specification.Model Specification.Model Specification.booleanhasInput()Input data.booleanModel Specification.protected com.google.protobuf.GeneratedMessage.FieldAccessorTablefinal booleanmergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) mergeFrom(com.google.protobuf.Message other) mergeInput(InputOuterClass.Input value) Input data.mergeModelSpec(Model.ModelSpec value) Model Specification.setInput(InputOuterClass.Input value) Input data.setInput(InputOuterClass.Input.Builder builderForValue) Input data.setModelSpec(Model.ModelSpec value) Model Specification.setModelSpec(Model.ModelSpec.Builder builderForValue) Model Specification.Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageExceptionMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.Message.Builder
mergeDelimitedFrom, mergeDelimitedFromMethods inherited from interface com.google.protobuf.MessageLite.Builder
mergeFromMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<Classification.ClassificationRequest.Builder>
-
clear
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<Classification.ClassificationRequest.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<Classification.ClassificationRequest.Builder>
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Classification.ClassificationRequest.Builder>
-
mergeFrom
public Classification.ClassificationRequest.Builder mergeFrom(Classification.ClassificationRequest other) -
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<Classification.ClassificationRequest.Builder>
-
mergeFrom
public Classification.ClassificationRequest.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Classification.ClassificationRequest.Builder>- Throws:
IOException
-
hasModelSpec
public boolean hasModelSpec()Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1;- Specified by:
hasModelSpecin interfaceClassification.ClassificationRequestOrBuilder- Returns:
- Whether the modelSpec field is set.
-
getModelSpec
Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1;- Specified by:
getModelSpecin interfaceClassification.ClassificationRequestOrBuilder- Returns:
- The modelSpec.
-
setModelSpec
Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1; -
setModelSpec
public Classification.ClassificationRequest.Builder setModelSpec(Model.ModelSpec.Builder builderForValue) Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1; -
mergeModelSpec
Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1; -
clearModelSpec
Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1; -
getModelSpecBuilder
Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1; -
getModelSpecOrBuilder
Model Specification. If version is not specified, will use the latest (numerical) version.
.tensorflow.serving.ModelSpec model_spec = 1;- Specified by:
getModelSpecOrBuilderin interfaceClassification.ClassificationRequestOrBuilder
-
hasInput
public boolean hasInput()Input data.
.tensorflow.serving.Input input = 2;- Specified by:
hasInputin interfaceClassification.ClassificationRequestOrBuilder- Returns:
- Whether the input field is set.
-
getInput
Input data.
.tensorflow.serving.Input input = 2;- Specified by:
getInputin interfaceClassification.ClassificationRequestOrBuilder- Returns:
- The input.
-
setInput
Input data.
.tensorflow.serving.Input input = 2; -
setInput
public Classification.ClassificationRequest.Builder setInput(InputOuterClass.Input.Builder builderForValue) Input data.
.tensorflow.serving.Input input = 2; -
mergeInput
Input data.
.tensorflow.serving.Input input = 2; -
clearInput
Input data.
.tensorflow.serving.Input input = 2; -
getInputBuilder
Input data.
.tensorflow.serving.Input input = 2; -
getInputOrBuilder
Input data.
.tensorflow.serving.Input input = 2;- Specified by:
getInputOrBuilderin interfaceClassification.ClassificationRequestOrBuilder
-