Package tensorflow.serving
Class FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder
java.lang.Object
com.google.protobuf.AbstractMessageLite.Builder
com.google.protobuf.AbstractMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
com.google.protobuf.GeneratedMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
tensorflow.serving.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder
- All Implemented Interfaces:
com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Cloneable,FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.SpecificOrBuilder
- Enclosing class:
FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific
public static final class FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder
extends com.google.protobuf.GeneratedMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
implements FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.SpecificOrBuilder
Serve a specific version (or set of versions). This policy is useful for rolling back to a specific version, or for canarying a specific version while still serving a separate stable version.Protobuf type
tensorflow.serving.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific-
Method Summary
Modifier and TypeMethodDescriptionFileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuilderaddAllVersions(Iterable<? extends Long> values) The version numbers to serve.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuilderaddVersions(long value) The version numbers to serve.build()FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builderclear()FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuilderThe version numbers to serve.static final com.google.protobuf.Descriptors.Descriptorcom.google.protobuf.Descriptors.DescriptorlonggetVersions(int index) The version numbers to serve.intThe version numbers to serve.The version numbers to serve.protected com.google.protobuf.GeneratedMessage.FieldAccessorTablefinal booleanFileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuildermergeFrom(com.google.protobuf.Message other) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuildermergeFrom(FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific other) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.BuildersetVersions(int index, long value) The version numbers to serve.Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageExceptionMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.Message.Builder
mergeDelimitedFrom, mergeDelimitedFromMethods inherited from interface com.google.protobuf.MessageLite.Builder
mergeFromMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
-
clear
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder clear()- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
-
getDefaultInstanceForType
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific getDefaultInstanceForType()- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific build()- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific buildPartial()- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder mergeFrom(com.google.protobuf.Message other) - Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
-
mergeFrom
-
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>
-
mergeFrom
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder>- Throws:
IOException
-
getVersionsList
The version numbers to serve.
repeated int64 versions = 1;- Specified by:
getVersionsListin interfaceFileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.SpecificOrBuilder- Returns:
- A list containing the versions.
-
getVersionsCount
public int getVersionsCount()The version numbers to serve.
repeated int64 versions = 1;- Specified by:
getVersionsCountin interfaceFileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.SpecificOrBuilder- Returns:
- The count of versions.
-
getVersions
public long getVersions(int index) The version numbers to serve.
repeated int64 versions = 1;- Specified by:
getVersionsin interfaceFileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.SpecificOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The versions at the given index.
-
setVersions
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder setVersions(int index, long value) The version numbers to serve.
repeated int64 versions = 1;- Parameters:
index- The index to set the value at.value- The versions to set.- Returns:
- This builder for chaining.
-
addVersions
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder addVersions(long value) The version numbers to serve.
repeated int64 versions = 1;- Parameters:
value- The versions to add.- Returns:
- This builder for chaining.
-
addAllVersions
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder addAllVersions(Iterable<? extends Long> values) The version numbers to serve.
repeated int64 versions = 1;- Parameters:
values- The versions to add.- Returns:
- This builder for chaining.
-
clearVersions
public FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableVersionPolicy.Specific.Builder clearVersions()The version numbers to serve.
repeated int64 versions = 1;- Returns:
- This builder for chaining.
-