Package tensorflow.serving
Class GetModelStatus.GetModelStatusRequest.Builder
java.lang.Object
com.google.protobuf.AbstractMessageLite.Builder
com.google.protobuf.AbstractMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
com.google.protobuf.GeneratedMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
tensorflow.serving.GetModelStatus.GetModelStatusRequest.Builder
- All Implemented Interfaces:
com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Cloneable,GetModelStatus.GetModelStatusRequestOrBuilder
- Enclosing class:
GetModelStatus.GetModelStatusRequest
public static final class GetModelStatus.GetModelStatusRequest.Builder
extends com.google.protobuf.GeneratedMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
implements GetModelStatus.GetModelStatusRequestOrBuilder
GetModelStatusRequest contains a ModelSpec indicating the model for which to get status.Protobuf type
tensorflow.serving.GetModelStatusRequest-
Method Summary
Modifier and TypeMethodDescriptionbuild()clear()Model Specification.static final com.google.protobuf.Descriptors.Descriptorcom.google.protobuf.Descriptors.DescriptorModel Specification.Model Specification.Model Specification.booleanModel Specification.protected com.google.protobuf.GeneratedMessage.FieldAccessorTablefinal booleanmergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) mergeFrom(com.google.protobuf.Message other) mergeModelSpec(Model.ModelSpec value) Model Specification.setModelSpec(Model.ModelSpec value) Model Specification.setModelSpec(Model.ModelSpec.Builder builderForValue) Model Specification.Methods inherited from class com.google.protobuf.GeneratedMessage.Builder
addRepeatedField, clearField, clearOneof, clone, getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownFields, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setField, setRepeatedField, setUnknownFields, setUnknownFieldSetBuilder, setUnknownFieldsProto3Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageExceptionMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.Message.Builder
mergeDelimitedFrom, mergeDelimitedFromMethods inherited from interface com.google.protobuf.MessageLite.Builder
mergeFromMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Method Details
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
-
clear
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
mergeFrom
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
-
mergeFrom
public GetModelStatus.GetModelStatusRequest.Builder mergeFrom(GetModelStatus.GetModelStatusRequest other) -
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>
-
mergeFrom
public GetModelStatus.GetModelStatusRequest.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<GetModelStatus.GetModelStatusRequest.Builder>- Throws:
IOException
-
hasModelSpec
public boolean hasModelSpec()Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1;- Specified by:
hasModelSpecin interfaceGetModelStatus.GetModelStatusRequestOrBuilder- Returns:
- Whether the modelSpec field is set.
-
getModelSpec
Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1;- Specified by:
getModelSpecin interfaceGetModelStatus.GetModelStatusRequestOrBuilder- Returns:
- The modelSpec.
-
setModelSpec
Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1; -
setModelSpec
public GetModelStatus.GetModelStatusRequest.Builder setModelSpec(Model.ModelSpec.Builder builderForValue) Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1; -
mergeModelSpec
Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1; -
clearModelSpec
Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1; -
getModelSpecBuilder
Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1; -
getModelSpecOrBuilder
Model Specification. If version is not specified, information about all versions of the model will be returned. If a version is specified, the status of only that version will be returned.
.tensorflow.serving.ModelSpec model_spec = 1;- Specified by:
getModelSpecOrBuilderin interfaceGetModelStatus.GetModelStatusRequestOrBuilder
-