Class InputOuterClass.ExampleListWithContext

java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessage
tensorflow.serving.InputOuterClass.ExampleListWithContext
All Implemented Interfaces:
com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable, InputOuterClass.ExampleListWithContextOrBuilder
Enclosing class:
InputOuterClass

public static final class InputOuterClass.ExampleListWithContext extends com.google.protobuf.GeneratedMessage implements InputOuterClass.ExampleListWithContextOrBuilder
 Specifies one or more independent input Examples, with a common context
 Example.

 The common use case for context is to cleanly and optimally specify some
 features that are common across multiple examples.

 See example below with a search query as the context and multiple restaurants
 to perform some inference on.

 context: {
 features: {
 feature: {
 key  : "query"
 value: {
 bytes_list: {
 value: [ "pizza" ]
 }
 }
 }
 }
 }
 examples: {
 features: {
 feature: {
 key  : "cuisine"
 value: {
 bytes_list: {
 value: [ "Pizzeria" ]
 }
 }
 }
 }
 }
 examples: {
 features: {
 feature: {
 key  : "cuisine"
 value: {
 bytes_list: {
 value: [ "Taqueria" ]
 }
 }
 }
 }
 }

 Implementations of ExampleListWithContext merge the context Example into each
 of the Examples. Note that feature keys must not be duplicated between the
 Examples and context Example, or the behavior is undefined.

 See also:
 tensorflow/core/example/example.proto
 https://developers.google.com/protocol-buffers/docs/proto3#maps
 
Protobuf type tensorflow.serving.ExampleListWithContext
See Also: