Uses of Class
tensorflow.serving.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder
Packages that use FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder
-
Uses of FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder in tensorflow.serving
Methods in tensorflow.serving that return FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.BuilderModifier and TypeMethodDescriptionFileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.addAllServables(Iterable<? extends FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor> values) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.addServables(int index, FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor value) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.addServables(int index, FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor.Builder builderForValue) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.addServables(FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor value) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.addServables(FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor.Builder builderForValue) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.clear()FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.clearFailIfZeroVersionsAtStartup()Deprecated.tensorflow.serving.FileSystemStoragePathSourceConfig.fail_if_zero_versions_at_startup is deprecated.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.clearFileSystemPollWaitSeconds()How long to wait between file-system polling to look for children of 'base_path', in seconds.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.clearServables()The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.clearServableVersionsAlwaysPresent()If true, the servable is always expected to exist on the underlying filesystem.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.mergeFrom(com.google.protobuf.Message other) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.mergeFrom(FileSystemStoragePathSource.FileSystemStoragePathSourceConfig other) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.newBuilder()FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.newBuilder(FileSystemStoragePathSource.FileSystemStoragePathSourceConfig prototype) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.newBuilderForType()FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.newBuilderForType(com.google.protobuf.AbstractMessage.BuilderParent parent) FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.removeServables(int index) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.setFailIfZeroVersionsAtStartup(boolean value) Deprecated.tensorflow.serving.FileSystemStoragePathSourceConfig.fail_if_zero_versions_at_startup is deprecated.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.setFileSystemPollWaitSeconds(long value) How long to wait between file-system polling to look for children of 'base_path', in seconds.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.setServables(int index, FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor value) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.setServables(int index, FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.ServableToMonitor.Builder builderForValue) The servables to monitor for new versions, and aspire.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.Builder.setServableVersionsAlwaysPresent(boolean value) If true, the servable is always expected to exist on the underlying filesystem.FileSystemStoragePathSource.FileSystemStoragePathSourceConfig.toBuilder()